pub trait TableViewRow<Context> {
// Required methods
fn table_view_header(
ctx: Context,
) -> Box<dyn AsRef<[(Cow<'static, str>, Unit, ColumnFormatting)]>>;
fn table_view_row(&self, out: &mut Vec<(Cow<'_, str>, Highlight)>);
}Required Methods
Sourcefn table_view_header(
ctx: Context,
) -> Box<dyn AsRef<[(Cow<'static, str>, Unit, ColumnFormatting)]>>
fn table_view_header( ctx: Context, ) -> Box<dyn AsRef<[(Cow<'static, str>, Unit, ColumnFormatting)]>>
Column names and unit. Not dyn compatible, must be static because it needs to be available for tables in the absense of rows. But to accommodate for dynamically decided changes, takes a context argument (which could be ()).
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.